@@ -1,6 +1,6 @@
-/*  controls.h
+/*  $Id: controls.h,v 1.30 2004/09/19 09:29:16 jasper Exp $
  *  
- *  Copyright (C) 2002 Jasper Huijsmans (huysmans@users.sourceforge.net)
+ *  Copyright (C) 2002-2004 Jasper Huijsmans (jasper@xfce.org)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -47,12 +47,15 @@ struct _ControlClass
 			     GCallback callback, gpointer data);
 
     void (*create_options) (Control * control, GtkContainer * container,
-			 GtkWidget * done);
+			    GtkWidget * done);
 
     /* global preferences */
     void (*set_orientation) (Control * control, int orientation);
     void (*set_size) (Control * control, int size);
     void (*set_theme) (Control * control, const char *theme);
+
+    /* open about dialog */
+    void (*about) (void);
 };
 
 struct _Control
@@ -69,39 +72,62 @@ struct _Control
 
 #define CONTROL_CLASS(cc) ((ControlClass*) cc)
 
-/* control class list */
-void control_class_list_init (void);
+/* for add-control-dialog.c */
+typedef struct
+{
+    char *name;
+    char *caption;
+    GdkPixbuf *icon;
+    gboolean can_be_added;	/* not unique or not already added */
+}
+ControlInfo;
 
-void control_class_list_cleanup (void);
+G_MODULE_IMPORT GSList *get_control_info_list (void);
 
-GSList *get_control_class_list (void);
+G_MODULE_IMPORT void insert_control (Panel * panel, const char *name, int position);
 
-/* add controls menu */
-void free_controls_menu_entries (GtkItemFactoryEntry * entries, int n);
-int get_controls_menu_entries (GtkItemFactoryEntry ** entries,
-			       const char *base);
+/* control classes */
+G_MODULE_IMPORT void control_class_list_init (void);
+
+G_MODULE_IMPORT void control_class_list_cleanup (void);
+
+/* NOTE:
+ * Use next functions only on classes that have at least 
+ * their name field initialized */
+G_MODULE_IMPORT void control_class_set_icon (ControlClass * cclass, GdkPixbuf * icon);
+
+G_MODULE_IMPORT void control_class_set_unique (ControlClass * cclass, gboolean unique);
+
+G_MODULE_IMPORT void control_class_set_unloadable (ControlClass * cclass,
+				   gboolean unloadable);
 
 /* controls */
-Control *control_new (int index);
-void create_control (Control * control, int id, const char *filename);
-void control_free (Control * control);
+G_MODULE_IMPORT Control *control_new (int index);
 
-void control_set_from_xml (Control * control, xmlNodePtr node);
-void control_write_xml (Control * control, xmlNodePtr parent);
+G_MODULE_IMPORT gboolean create_control (Control * control, int id, const char *filename);
 
-void control_pack (Control * control, GtkBox * box);
-void control_unpack (Control * control);
+G_MODULE_IMPORT void control_free (Control * control);
 
-void control_attach_callbacks (Control * control);
+G_MODULE_IMPORT gboolean control_set_from_xml (Control * control, xmlNodePtr node);
 
-void control_create_options (Control * control, GtkContainer * container,
-			  GtkWidget * done);
+G_MODULE_IMPORT void control_write_xml (Control * control, xmlNodePtr parent);
+
+G_MODULE_IMPORT void control_pack (Control * control, GtkBox * box);
+
+G_MODULE_IMPORT void control_unpack (Control * control);
+
+G_MODULE_IMPORT void control_attach_callbacks (Control * control);
+
+G_MODULE_IMPORT void control_create_options (Control * control, GtkContainer * container,
+			     GtkWidget * done);
 
 /* global settings */
-void control_set_settings (Control * control);
+G_MODULE_IMPORT void control_set_settings (Control * control);
 
-void control_set_orientation (Control * control, int orientation);
-void control_set_size (Control * control, int size);
-void control_set_theme (Control * control, const char *theme);
+G_MODULE_IMPORT void control_set_orientation (Control * control, int orientation);
+
+G_MODULE_IMPORT void control_set_size (Control * control, int size);
+
+G_MODULE_IMPORT void control_set_theme (Control * control, const char *theme);
 
 #endif /* __XFCE_CONTROLS_H__ */
