@@ -1,4 +1,4 @@
-/*  $Id: item_dialog.c,v 1.74.2.1 2005/01/08 09:04:47 jasper Exp $
+/*  $Id: item_dialog.c,v 1.74.2.2 2005/02/16 20:06:02 jasper Exp $
  *
  *  Copyright (C) 2002-2004 Jasper Huijsmans (jasper@xfce.org)
  *
@@ -92,8 +92,7 @@ static const char *keys[] = {
     "Categories",
     "OnlyShowIn",
     "Exec",
-    "Terminal",
-    NULL
+    "Terminal"
 };
 
 /* useful widgets */
