@@ -1,4 +1,4 @@
-/*  $Id: main.c,v 1.64 2004/12/14 11:51:09 jasper Exp $
+/*  $Id: main.c,v 1.64.2.1 2005/02/16 20:06:02 jasper Exp $
  *
  *  Copyright (c) 2002-2004 Jasper Huijsmans <jasper@xfce.org>
  *  Copyright (c) 2003 Benedikt Meurer <benedikt.meurer@xfce.org>
@@ -87,8 +87,7 @@ static gboolean session_managed = FALSE;
 static void
 save_panel (void)
 {
-    if (!disable_user_config)
-	write_panel_config ();
+    write_final_panel_config ();
 }
 
 static void
