@@ -1,4 +1,4 @@
-/*  $Id: xfce_support.c,v 1.68 2004/11/06 13:11:40 jasper Exp $
+/*  $Id: xfce_support.c,v 1.69.2.1 2005/01/17 00:54:49 kelnos Exp $
  *  
  *  Copyright 2002-2004 Jasper Huijsmans (jasper@xfce.org)
  *  
@@ -194,7 +194,8 @@ write_backup_file (const char * path)
 {
     FILE *fp;
     FILE *bakfp;
-    char bakfile[MAXSTRLEN + 1], c;
+    char bakfile[MAXSTRLEN + 1];
+    int c;
 
     snprintf (bakfile, MAXSTRLEN, "%s.bak", path);
 
@@ -570,7 +571,7 @@ real_select_file (const char *title, const char *path,
             char *current, *full;
 
             current = g_get_current_dir ();
-            full = g_build_filename (current, path);
+            full = g_build_filename (current, path, NULL);
 
             xfce_file_chooser_set_filename(XFCE_FILE_CHOOSER(fs), full);
 
