@@ -1,4 +1,4 @@
-/*  $Id: clock.c,v 1.37 2004/09/26 11:55:20 jasper Exp $
+/*  $Id: clock.c,v 1.37.2.2 2005/03/07 20:51:48 jasper Exp $
  *
  *  Copyright 2002,2004 Jasper Huijsmans(jasper@xfce.org)
  *                      Olivier Fourdan (fourdan@xfce.org)
@@ -91,14 +91,12 @@ ClockDialog;
 
 /* start xfcalendar or send a client message
  * NOTE: keep message format in sync with xfcalendar */
-static gboolean retry_popup_xfcalendar (GtkWidget * widget);
 
 static gboolean
-popup_xfcalendar (GtkWidget * widget, guint32 time)
+popup_xfcalendar (GtkWidget * widget)
 {
     GdkAtom atom;
     Window xwindow;
-    static guint32 start_time = 0;
 
     /* send message to xfcalendar if it is running */
     atom = gdk_atom_intern ("_XFCE_CALENDAR_RUNNING", FALSE);
@@ -143,30 +141,22 @@ popup_xfcalendar (GtkWidget * widget, guint32 time)
 
 	return TRUE;
     }
-    else if (time > start_time + 2000 || start_time == 0)
+    else 
     {
-	start_time = time;
 	exec_cmd_silent ("xfcalendar", FALSE, FALSE);
-	g_timeout_add (1000, (GSourceFunc) retry_popup_xfcalendar, widget);
+    exec_cmd_silent ("xfcalendar", FALSE, FALSE); /* actually only RAISE */
     }
 
     return FALSE;
 }
 
-static gboolean
-retry_popup_xfcalendar (GtkWidget * widget)
-{
-    popup_xfcalendar (widget, gtk_get_current_event_time ());
-    return FALSE;
-}
-
 static gboolean
 on_button_press_event_cb (GtkWidget * widget,
 			  GdkEventButton * event, Control * control)
 {
     if (event->button == 1)
     {
-	return popup_xfcalendar (control->base, event->time);
+	return popup_xfcalendar (control->base);
     }
 
     return FALSE;
@@ -182,8 +172,8 @@ clock_date_tooltip (GtkWidget * widget)
     char date_s[255];
     char *utf8date = NULL;
 
-    g_return_val_if_fail (widget != NULL, FALSE);
-    g_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
+    g_return_val_if_fail (widget != NULL, TRUE);
+    g_return_val_if_fail (GTK_IS_WIDGET (widget), TRUE);
 
     ticks = time (0);
     tm = localtime (&ticks);
@@ -256,7 +246,10 @@ clock_free (Control * control)
     g_return_if_fail (clock != NULL);
 
     if (clock->timeout_id)
+    {
 	g_source_remove (clock->timeout_id);
+        clock->timeout_id = 0;
+    }
 
     g_free (clock);
 }
