@@ -1,4 +1,4 @@
-/*  $Id: xfce_settings_plugin.c,v 1.27 2004/09/12 16:39:31 jasper Exp $
+/*  $Id: xfce_settings_plugin.c,v 1.28.2.1 2005/02/01 07:30:36 jasper Exp $
  *
  *  Copyright 2002-2004 Jasper Huijsmans (jasper@xfce.org)
  *
@@ -100,7 +100,8 @@ ensure_base_dir_spec (XfceResourceType type,
                       const char *old_subdir, const char *old_file,
                       const char *new_subdir, const char *new_file)
 {
-    char  *old, *new, *path, c;
+    char  *old, *new, *path;
+    int c;
     FILE *r, *w;
     GError *error = NULL;
 
@@ -237,7 +238,7 @@ old_xml_read_options (const char *path)
     GMarkupParser *parser;
     GMarkupParseContext *context;
     char *contents;
-    int len;
+    gsize len;
     GError *error = NULL;
 
     if (!g_file_get_contents (path, &contents, &len, &error))
